pub struct ListCommitsOptions {
pub sha: Option<String>,
pub path: Option<String>,
pub author: Option<String>,
pub since: Option<String>,
pub until: Option<String>,
pub page: Option<u32>,
pub per_page: Option<u8>,
}Expand description
Options for listing commits in a repository.
Fields
sha: Option<String>SHA or branch to start listing commits from.
path: Option<String>Only commits containing this file path will be returned.
GitHub login or email address to filter commits by author.
since: Option<String>Only show commits after this date (ISO 8601 format).
until: Option<String>Only show commits before this date (ISO 8601 format).
page: Option<u32>Page number of results to return.
per_page: Option<u8>Number of results per page (max 100).